==> pdapi-0.1.3-sources.jar: ml/pluto7073/pdapi/item/AbstractCustomizableDrinkItem.java <==
package ml.pluto7073.pdapi.item;

import ml.pluto7073.pdapi.DrinkUtil;
import ml.pluto7073.pdapi.addition.DrinkAddition;
import ml.pluto7073.pdapi.addition.DrinkAdditions;
import net.minecraft.class_124;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_174;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1839;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_3468;
import net.minecraft.class_5328;
import net.minecraft.class_5712;
import net.minecraft.util.*;
import org.jetbrains.annotations.Nullable;

import java.util.HashMap;
import java.util.List;

public abstract class AbstractCustomizableDrinkItem extends class_1792 {

    public static final String DRINK_DATA_NBT_KEY = "DrinkData";

    private static final int MAX_USE_TIME = 32;

    protected final Temperature baseTemperature;
    protected final class_1792 baseItem;

    protected AbstractCustomizableDrinkItem(class_1792 baseItem, Temperature baseTemperature, class_1793 settings) {
        super(settings);
        this.baseTemperature = baseTemperature;
        this.baseItem = baseItem;
    }

    public Temperature getDrinkTemperature(class_1799 stack) {
        return baseTemperature;
    }

    public int getCaffeineContent(class_1799 stack) {
        int caffeine = 0;
        for (DrinkAddition a : DrinkUtil.getAdditionsFromStack(stack)) {
            caffeine += a.getCaffeine();
        }
        return caffeine;
    }

    @Override
    public int method_7881(class_1799 stack) {
        return MAX_USE_TIME;
    }

    @Override
    public class_1839 method_7853(class_1799 stack) {
        return class_1839.field_8946;
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        return class_5328.method_29282(world, user, hand);
    }

    @Override
    public class_1799 method_7861(class_1799 stack, class_1937 world, class_1309 user) {
        class_1657 playerEntity = user instanceof class_1657 ? (class_1657) user : null;
        if (playerEntity instanceof class_3222) {
            class_174.field_1198.method_8821((class_3222)playerEntity, stack);
        }

        if (!world.field_9236) {
            DrinkAddition[] additions = DrinkUtil.getAdditionsFromStack(stack);
            for (DrinkAddition addition : additions) {
                addition.onDrink(stack, world, user);
            }
            int caffeine = this.getCaffeineContent(stack);
            if (playerEntity != null) {
                float currentCaffeine = DrinkUtil.getPlayerCaffeine(playerEntity);
                currentCaffeine += caffeine;
                DrinkUtil.setPlayerCaffeine(playerEntity, currentCaffeine);
            }
        }

        if (playerEntity != null) {
            playerEntity.method_7259(class_3468.field_15372.method_14956(this));
            if (!playerEntity.method_31549().field_7477) {
                stack.method_7934(1);
            }
        }

        if (playerEntity == null || !playerEntity.method_31549().field_7477) {
            if (stack.method_7960()) {
                return new class_1799(baseItem);
            }

            if (playerEntity != null) {
                playerEntity.method_31548().method_7394(new class_1799(baseItem));
            }
        }
        user.method_32876(class_5712.field_28734);
        return stack;
    }

    @Override
    public void method_7851(class_1799 stack, @Nullable class_1937 world, List<class_2561> tooltip, class_1836 context) {
        float caffeine = getCaffeineContent(stack);
        DrinkAddition[] addIns = DrinkUtil.getAdditionsFromStack(stack);
        HashMap<class_2960, Integer> additionCounts = new HashMap<>();
        for (DrinkAddition addIn : addIns) {
            if (addIn == DrinkAdditions.EMPTY) continue;
            class_2960 id = DrinkAdditions.getId(addIn);
            if (additionCounts.containsKey(id)) {
                int count = additionCounts.get(id);
                additionCounts.put(id, ++count);
            } else additionCounts.put(id, 1);
        }
        additionCounts.forEach((id, count) -> tooltip.add(class_2561.method_43469(DrinkAdditions.get(id).getTranslationKey(), count).method_27692(class_124.field_1080)));
        if (caffeine > 0) tooltip.add(class_2561.method_43469("tooltip.pdapi.caffeine_content", caffeine).method_27692(class_124.field_1075));
    }

    public enum Temperature {
        BURNT, HOT, NORMAL, COLD, FROZEN
    }

}

==> pdapi-1.20.1+0.1.6.6-sources.jar: ml/pluto7073/pdapi/item/AbstractCustomizableDrinkItem.java <==
package ml.pluto7073.pdapi.item;

import ml.pluto7073.pdapi.DrinkUtil;
import ml.pluto7073.pdapi.addition.DrinkAddition;
import ml.pluto7073.pdapi.addition.DrinkAdditions;
import ml.pluto7073.pdapi.addition.chemicals.ConsumableChemicalRegistry;
import net.minecraft.class_124;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1309;
import net.minecraft.class_1657;
import net.minecraft.class_174;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1836;
import net.minecraft.class_1839;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_3468;
import net.minecraft.class_5328;
import net.minecraft.class_5712;
import net.minecraft.class_6328;
import net.minecraft.util.*;
import org.jetbrains.annotations.Nullable;

import java.util.HashMap;
import java.util.List;

@class_6328
public abstract class AbstractCustomizableDrinkItem extends class_1792 {

    public static final String DRINK_DATA_NBT_KEY = "DrinkData";

    private static final int MAX_USE_TIME = 32;

    protected final Temperature baseTemperature;
    protected final class_1792 baseItem;

    protected AbstractCustomizableDrinkItem(class_1792 baseItem, Temperature baseTemperature, class_1793 settings) {
        super(settings);
        this.baseTemperature = baseTemperature;
        this.baseItem = baseItem;
    }

    public Temperature getDrinkTemperature(class_1799 stack) {
        return baseTemperature;
    }

    public int getChemicalContent(String name, class_1799 stack) {
        int amount = 0;
        for (DrinkAddition a : DrinkUtil.getAdditionsFromStack(stack)) {
            amount += a.getChemicals().get(name);
        }
        return amount;
    }

    @Override
    public int method_7881(class_1799 stack) {
        return MAX_USE_TIME;
    }

    @Override
    public class_1839 method_7853(class_1799 stack) {
        return class_1839.field_8946;
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        return class_5328.method_29282(world, user, hand);
    }

    @Override
    public class_1799 method_7861(class_1799 stack, class_1937 world, class_1309 user) {
        class_1657 player = user instanceof class_1657 ? (class_1657) user : null;
        if (player instanceof class_3222) {
            class_174.field_1198.method_8821((class_3222)player, stack);
        }

        if (!world.field_9236) {
            DrinkAddition[] additions = DrinkUtil.getAdditionsFromStack(stack);
            for (DrinkAddition addition : additions) {
                addition.onDrink(stack, world, user);
            }
            if (player != null) {
                ConsumableChemicalRegistry.forEach(handler -> {
                    float amount = getChemicalContent(handler.getName(), stack);
                    if (amount > 0) handler.add(player, amount);
                });
            }
        }

        if (player != null) {
            player.method_7259(class_3468.field_15372.method_14956(this));
            if (!player.method_31549().field_7477) {
                stack.method_7934(1);
            }
        }

        if (player == null || !player.method_31549().field_7477) {
            if (stack.method_7960()) {
                return new class_1799(baseItem);
            }

            if (player != null) {
                player.method_31548().method_7394(new class_1799(baseItem));
            }
        }
        user.method_32876(class_5712.field_28734);
        return stack;
    }

    @Override
    public void method_7851(class_1799 stack, @Nullable class_1937 world, List<class_2561> tooltip, class_1836 context) {
        DrinkAddition[] addIns = DrinkUtil.getAdditionsFromStack(stack);
        HashMap<class_2960, Integer> additionCounts = new HashMap<>();
        for (DrinkAddition addIn : addIns) {
            if (addIn == DrinkAdditions.EMPTY) continue;
            class_2960 id = DrinkAdditions.getId(addIn);
            if (additionCounts.containsKey(id)) {
                int count = additionCounts.get(id);
                additionCounts.put(id, ++count);
            } else additionCounts.put(id, 1);
        }
        additionCounts.forEach((id, count) -> tooltip.add(class_2561.method_43469(DrinkAdditions.get(id).getTranslationKey(), count).method_27692(class_124.field_1080)));
        ConsumableChemicalRegistry.forEach(handler ->
                handler.appendTooltip(tooltip, getChemicalContent(handler.getName(), stack), stack));
    }

    public enum Temperature {
        BURNT, HOT, NORMAL, COLD, FROZEN
    }

}
